==> cherrytree_0.29.orig.tar.xz: cherrytree-0.29/glade/cherrytree.glade.h <==
char *s = N_("About CherryTree");
char *s = N_("Copyright © 2009-2012\n"
             "Giuseppe Penone <giuspen@gmail.com>");
char *s = N_("A Hierarchical Note Taking Application, featuring Rich Text and Syntax Highlighting");
char *s = N_("http://www.giuspen.com/cherrytree/");
char *s = N_("\n"
             "This program is free software; you can redistribute it and/or modify\n"
             "it under the terms of the GNU General Public License as published by\n"
             "the Free Software Foundation; either version 2 of the License, or\n"
             "(at your option) any later version.\n"
             "  \n"
             "This program is distributed in the hope that it will be useful,\n"
             "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
             "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
             "GNU General Public License for more details.\n"
             "  \n"
             "You should have received a copy of the GNU General Public License\n"
             "along with this program; if not, write to the Free Software\n"
             "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,\n"
             "MA 02110-1301, USA.\n"
             "");
char *s = N_("Chinese Simplified (zh_CN) Channing Wong <mamimoluo@gmail.com>\n"
             "Czech (cs) Pavel Fric <fripohled@blogspot.com>\n"
             "French (fr) Ludovic Troisi <axalis@cegetel.net>\n"
             "German (de) Frank Brungräber <calexu@arcor.de> (former Sven Neubauer)\n"
             "Italian (it) Giuseppe Penone <giuspen@gmail.com>\n"
             "Polish (pl) Marcin Swierczynski <orneo1212@gmail.com>\n"
             "Russian (ru) Andriy Kovtun <kovtunos@yandex.ru>\n"
             "Spanish (es) Daniel MC <i.e.betel@gmail.com>\n"
             "Ukrainian (uk) Andriy Kovtun <kovtunos@yandex.ru>");
char *s = N_("Hide (Restore with Ctrl+Shift+A)");
char *s = N_("Cancel");
char *s = N_("OK");
char *s = N_("Select the New Father");
char *s = N_("To WebSite");
char *s = N_("To Node");
char *s = N_("To File");
char *s = N_("To Folder");
char *s = N_("<b>Type</b>");
char *s = N_("<b>WebSite URL</b>");
char *s = N_("Browse for a File to link to");
char *s = N_("<b>File/Folder Path</b>");
char *s = N_("<b>Node</b>");
char *s = N_("<b>Anchor Name (optional)</b>");
char *s = N_("<b>Automatic Syntax Highlighting</b>");
char *s = N_("Width");
char *s = N_("pixels");
/* xgettext:no-c-format */
char *s = N_("%");
char *s = N_("Height");
char *s = N_("<b>Size</b>");
char *s = N_("Show Line Numbers");
char *s = N_("Highlight Matching Brackets");
char *s = N_("<b>Options</b>");
char *s = N_("Pick a Color");
char *s = N_("Warning");
char *s = N_("No");
char *s = N_("Yes");
char *s = N_("<b>The current document was updated</b>,\n"
             "do you want to save the changes?");
char *s = N_("Image Properties");
char *s = N_("Input Dialog");
char *s = N_("<b>Replace with</b>");
char *s = N_("Match Case");
char *s = N_("Regular Expression");
char *s = N_("Whole Word");
char *s = N_("Start Word");
char *s = N_("Forward");
char *s = N_("Backward");
char *s = N_("All, List Matches");
char *s = N_("First From Selection");
char *s = N_("First in All Range");
char *s = N_("Show Iterated Find/Replace Dialog");
char *s = N_("<b>Search options</b>");
char *s = N_("Rich Text");
char *s = N_("Automatic Syntax Highlighting");
char *s = N_("<b>Node Type</b>");
char *s = N_("<b>Tags for Searching</b>");
char *s = N_("Read Only");
char *s = N_("Iterate Latest Find/Replace");
char *s = N_("Close");
char *s = N_("Iterate the Last Find Operation in Opposite Direction");
char *s = N_("Find");
char *s = N_("Iterate the Last Find Operation");
char *s = N_("Replace");
char *s = N_("Undo the Latest Replace");
char *s = N_("Undo");
char *s = N_("Are you sure to Delete the node?");
char *s = N_("Preferences");
char *s = N_("Tab Width  ");
char *s = N_("Insert Spaces Instead of Tabs");
char *s = N_("Use Line Wrapping");
char *s = N_("Enable Automatic Indentation");
char *s = N_("<b>Text Editor</b>");
char *s = N_("Timestamp Format");
char *s = N_("Horizontal Rule");
char *s = N_("<b>Miscellaneous</b>");
char *s = N_("All Nodes");
char *s = N_("Light Background, Dark Text");
char *s = N_("Dark Background, Light Text");
char *s = N_("Custom Background");
char *s = N_("and Text");
char *s = N_("<b>Theme</b>");
char *s = N_("Limit of Undoable Steps Per Node");
char *s = N_("Text Nodes");
char *s = N_("Style Scheme");
char *s = N_("Show White Spaces");
char *s = N_("Highlight Current Line");
char *s = N_("Code Nodes");
char *s = N_("Use Cherries as Nodes Icons");
char *s = N_("Use Bullets as Nodes Icons");
char *s = N_("Do Not Display Nodes Icons");
char *s = N_("<b>Nodes Icons</b>");
char *s = N_("Expand All Nodes When Loading the Tree");
char *s = N_("Tree Nodes Names Wrapping Width");
char *s = N_("Display Tree on the Right Side");
char *s = N_("Tree");
char *s = N_("Text Font");
char *s = N_("Code Font");
char *s = N_("Tree Font");
char *s = N_("<b>Fonts</b>");
char *s = N_("Fonts");
char *s = N_("Enable Custom Web Link Clicked Action");
char *s = N_("Enable Custom File Link Clicked Action");
char *s = N_("Enable Custom Folder Link Clicked Action");
char *s = N_("Anchor Size");
char *s = N_("<b>Links</b>");
char *s = N_("Links");
char *s = N_("Enable System Tray Docking");
char *s = N_("Start Minimized in the System Tray");
char *s = N_("Use AppIndicator for Docking");
char *s = N_("<b>System Tray</b>");
char *s = N_("Autosave Every");
char *s = N_("Minutes");
char *s = N_("Autosave on Quit");
char *s = N_("Create a Backup Copy Before Saving");
char *s = N_("<b>Saving</b>");
char *s = N_("Automatically Check for Newer Version");
char *s = N_("Reload After External Update to CT* File");
char *s = N_("<b>Language</b>");
char *s = N_("Miscellaneous");
char *s = N_("Rows  ");
char *s = N_("     Columns  ");
char *s = N_("<b>Table size</b>");
char *s = N_("Min Width");
char *s = N_("   Max Width");
char *s = N_("<b>Columns Properties</b>");
char *s = N_("Import from CSV File");
char *s = N_("Rename Column");
char *s = N_("Delete Column");
char *s = N_("Add Column");
char *s = N_("Move Column Left");
char *s = N_("Move Column Right");
char *s = N_("CherryTree");

==> cherrytree_0.30.5.orig.tar.xz: cherrytree-0.30.5/glade/cherrytree.glade.h <==
char *s = N_("About CherryTree");
char *s = N_("Copyright © 2009-2013\n"
             "Giuseppe Penone <giuspen@gmail.com>");
char *s = N_("A Hierarchical Note Taking Application, featuring Rich Text and Syntax Highlighting");
char *s = N_("http://www.giuspen.com/cherrytree/");
char *s = N_("\n"
             "This program is free software; you can redistribute it and/or modify\n"
             "it under the terms of the GNU General Public License as published by\n"
             "the Free Software Foundation; either version 3 of the License, or\n"
             "(at your option) any later version.\n"
             "  \n"
             "This program is distributed in the hope that it will be useful,\n"
             "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
             "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
             "GNU General Public License for more details.\n"
             "  \n"
             "You should have received a copy of the GNU General Public License\n"
             "along with this program; if not, write to the Free Software\n"
             "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,\n"
             "MA 02110-1301, USA.\n"
             "");
char *s = N_("Chinese Simplified (zh_CN) Channing Wong <mamimoluo@gmail.com>\n"
             "Czech (cs) Pavel Fric <fripohled@blogspot.com>\n"
             "French (fr) Benoît D'Angelo <benoit.dangelo@gmx.fr> (former Ludovic Troisi)\n"
             "German (de) Frank Brungräber <calexu@arcor.de> (former Sven Neubauer)\n"
             "Italian (it) Giuseppe Penone <giuspen@gmail.com>\n"
             "Polish (pl) Marcin Swierczynski <orneo1212@gmail.com>\n"
             "Portuguese Brazil (pt_BR) Vinicius Schmidt <viniciussm@rocketmail.com>\n"
             "Russian (ru) Andriy Kovtun <kovtunos@yandex.ru>\n"
             "Spanish (es) Daniel MC <i.e.betel@gmail.com>\n"
             "Ukrainian (uk) Andriy Kovtun <kovtunos@yandex.ru>");
char *s = N_("Hide (Restore with Ctrl+Shift+A)");
char *s = N_("Cancel");
char *s = N_("OK");
char *s = N_("Select the New Father");
char *s = N_("To WebSite");
char *s = N_("To Node");
char *s = N_("To File");
char *s = N_("To Folder");
char *s = N_("<b>Type</b>");
char *s = N_("<b>WebSite URL</b>");
char *s = N_("Browse for a File to link to");
char *s = N_("<b>File/Folder Path</b>");
char *s = N_("<b>Node</b>");
char *s = N_("<b>Anchor Name (optional)</b>");
char *s = N_("<b>Automatic Syntax Highlighting</b>");
char *s = N_("Width");
char *s = N_("pixels");
/* xgettext:no-c-format */
char *s = N_("%");
char *s = N_("Height");
char *s = N_("<b>Size</b>");
char *s = N_("Show Line Numbers");
char *s = N_("Highlight Matching Brackets");
char *s = N_("<b>Options</b>");
char *s = N_("Warning");
char *s = N_("No");
char *s = N_("Yes");
char *s = N_("<b>The current document was updated</b>,\n"
             "do you want to save the changes?");
char *s = N_("Image Properties");
char *s = N_("Iterate Latest Find/Replace");
char *s = N_("Close");
char *s = N_("Iterate the Last Find Operation in Opposite Direction");
char *s = N_("Find");
char *s = N_("Iterate the Last Find Operation");
char *s = N_("Replace");
char *s = N_("Undo the Latest Replace");
char *s = N_("Undo");
char *s = N_("Are you sure to Delete the node?");
char *s = N_("<b>Node Name</b>");
char *s = N_("Rich Text");
char *s = N_("Automatic Syntax Highlighting");
char *s = N_("<b>Node Type</b>");
char *s = N_("<b>Tags for Searching</b>");
char *s = N_("Read Only");
char *s = N_("Preferences");
char *s = N_("Tab Width  ");
char *s = N_("Insert Spaces Instead of Tabs");
char *s = N_("Use Line Wrapping");
char *s = N_("Enable Automatic Indentation");
char *s = N_("<b>Text Editor</b>");
char *s = N_("Timestamp Format");
char *s = N_("Horizontal Rule");
char *s = N_("Special Characters");
char *s = N_("<b>Miscellaneous</b>");
char *s = N_("All Nodes");
char *s = N_("Enable Spell Check");
char *s = N_("Spell Check Language");
char *s = N_("<b>Spell Check</b>");
char *s = N_("Light Background, Dark Text");
char *s = N_("Dark Background, Light Text");
char *s = N_("Custom Background");
char *s = N_("and Text");
char *s = N_("<b>Theme</b>");
char *s = N_("Limit of Undoable Steps Per Node");
char *s = N_("Text Nodes");
char *s = N_("Style Scheme");
char *s = N_("Show White Spaces");
char *s = N_("Highlight Current Line");
char *s = N_("Code Nodes");
char *s = N_("Use Cherries as Nodes Icons");
char *s = N_("Use Bullets as Nodes Icons");
char *s = N_("Do Not Display Nodes Icons");
char *s = N_("<b>Nodes Icons</b>");
char *s = N_("Restore Expanded/Collapsed Status");
char *s = N_("Expand all Nodes");
char *s = N_("Collapse all Nodes");
char *s = N_("<b>Nodes Status at Startup</b>");
char *s = N_("Tree Nodes Names Wrapping Width");
char *s = N_("Display Tree on the Right Side");
char *s = N_("Tree");
char *s = N_("Text Font");
char *s = N_("Code Font");
char *s = N_("Tree Font");
char *s = N_("<b>Fonts</b>");
char *s = N_("Fonts");
char *s = N_("Enable Custom Web Link Clicked Action");
char *s = N_("Enable Custom File Link Clicked Action");
char *s = N_("Enable Custom Folder Link Clicked Action");
char *s = N_("Anchor Size");
char *s = N_("<b>Links</b>");
char *s = N_("Links");
char *s = N_("Enable System Tray Docking");
char *s = N_("Start Minimized in the System Tray");
char *s = N_("Use AppIndicator for Docking");
char *s = N_("<b>System Tray</b>");
char *s = N_("Autosave Every");
char *s = N_("Minutes");
char *s = N_("Autosave on Quit");
char *s = N_("Create a Backup Copy Before Saving");
char *s = N_("<b>Saving</b>");
char *s = N_("Automatically Check for Newer Version");
char *s = N_("Reload Document From Last Session");
char *s = N_("Reload After External Update to CT* File");
char *s = N_("<b>Language</b>");
char *s = N_("Miscellaneous");
char *s = N_("<b>Search for</b>");
char *s = N_("<b>Replace with</b>");
char *s = N_("Match Case");
char *s = N_("Regular Expression");
char *s = N_("Whole Word");
char *s = N_("Start Word");
char *s = N_("Forward");
char *s = N_("Backward");
char *s = N_("All, List Matches");
char *s = N_("First From Selection");
char *s = N_("First in All Range");
char *s = N_("Show Iterated Find/Replace Dialog");
char *s = N_("<b>Search options</b>");
char *s = N_("Rows  ");
char *s = N_("     Columns  ");
char *s = N_("<b>Table size</b>");
char *s = N_("Min Width");
char *s = N_("   Max Width");
char *s = N_("<b>Columns Properties</b>");
char *s = N_("Import from CSV File");
char *s = N_("Rename Column");
char *s = N_("Delete Column");
char *s = N_("Add Column");
char *s = N_("Move Column Left");
char *s = N_("Move Column Right");
char *s = N_("CherryTree");
